@@ -4,6 +4,8 @@
 
 // region: mod, extern and use statements
 mod auto_cargo_toml_to_md_mod;
+mod auto_md_to_doc_comments_mod;
 
 // reexport objects for callers of the library
 pub use auto_cargo_toml_to_md_mod::auto_cargo_toml_to_md;
+pub use auto_md_to_doc_comments_mod::auto_md_to_doc_comments;
